@@ -53,7 +53,7 @@ class Account(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["AccountProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[AccountProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -226,7 +226,7 @@ class DBCluster(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["DBClusterProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[DBClusterProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -343,7 +343,7 @@ class DBClusterProps:
                 period: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
                 period_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
                 resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
-                tags: typing.Optional[typing.Sequence[typing.Union["RosDBCluster.TagsProperty", typing.Dict[str, typing.Any]]]] = None,
+                tags: typing.Optional[typing.Sequence[typing.Union[RosDBCluster.TagsProperty, typing.Dict[str, typing.Any]]]] = None,
                 zone_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
             ) -> None:
                 ...
@@ -631,7 +631,7 @@ class RosAccount(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosAccountProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosAccountProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -998,7 +998,7 @@ class RosDBCluster(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosDBClusterProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosDBClusterProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -1501,7 +1501,7 @@ class RosDBCluster(
     ) -> None:
         if __debug__:
             def stub(
-                value: typing.Optional[typing.List["RosDBCluster.TagsProperty"]],
+                value: typing.Optional[typing.List[RosDBCluster.TagsProperty]],
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
